# coding: utf-8

# flake8: noqa

"""
    Vayu Events Api

    The Vayu Event Ingestion API is a RESTful API that allows you to submit events for processing and storage. The API is secured using the Bearer Authentication scheme with JWT tokens. To obtain a JWT token, please contact Vayu at team@withvayu.com 

    The version of the OpenAPI document: 2.3.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from openapi_client.api.auth_api import AuthApi
from openapi_client.api.events_api import EventsApi

# import ApiClient
from openapi_client.api_response import ApiResponse
from openapi_client.api_client import ApiClient
from openapi_client.configuration import Configuration
from openapi_client.exceptions import OpenApiException
from openapi_client.exceptions import ApiTypeError
from openapi_client.exceptions import ApiValueError
from openapi_client.exceptions import ApiKeyError
from openapi_client.exceptions import ApiAttributeError
from openapi_client.exceptions import ApiException

# import models into sdk package
from openapi_client.models.event_input import EventInput
from openapi_client.models.login_request import LoginRequest
from openapi_client.models.login_response import LoginResponse
from openapi_client.models.send_events_request import SendEventsRequest



# coding: utf-8

# flake8: noqa
"""
    Vayu Events Api

    The Vayu Event Ingestion API is a RESTful API that allows you to submit events for processing and storage. The API is secured using the Bearer Authentication scheme with JWT tokens. To obtain a JWT token, please contact Vayu at team@withvayu.com 

    The version of the OpenAPI document: 2.3.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openapi_client.models.event_input import EventInput
from openapi_client.models.login_request import LoginRequest
from openapi_client.models.login_response import LoginResponse
from openapi_client.models.send_events_request import SendEventsRequest



from typing import List

from openapi_client.api import auth_api, events_api
from openapi_client.api_client import ApiClient
from openapi_client.configuration import Configuration
from openapi_client.models import EventInput
from openapi_client.models.login_request import LoginRequest
from openapi_client.models.send_events_request import SendEventsRequest
from vayu_consts import VAYU_URL


class Vayu:
    def __init__(self, api_key: str):
        self.__login(api_key)
    
    def send_events(self, events: List[EventInput]):
        """
        Send events to Weft

        Args:
            events ([EventInput]): events to send
        """

        events_api = self.__build_events_api(VAYU_URL)
        send_events_request = SendEventsRequest(events=events)

        return events_api.send_events(send_events_request)

    def __login(self, api_key: str):
        """
        Get new access token from refresh token (access token expires after 1 hour)

        Returns:
        str: access token
        """

        auth_api = self.__build_auth_api(VAYU_URL)
        refresh_token_input = LoginRequest(refreshToken=api_key)

        refresh_response = auth_api.login(refresh_token_input)

        self.__access_token = refresh_response.token
    
    def __build_auth_api(self, host: str):
        configuration = Configuration(host)
        client = ApiClient(configuration)
        
        return auth_api.AuthApi(client)

    def __build_events_api(self, host: str):
        configuration = Configuration(host=host)
        client = ApiClient(configuration, header_name='Authorization', header_value=f'Bearer {self.__access_token}')
        
        return events_api.EventsApi(client)
